@@ -59,6 +59,39 @@ def quoteCmdExe(string):
     else:
         return string
 
+def removeUserFromUrl(url):
+    """Remove the user information from an URL.
+
+    recognizes scp-like syntax as used by git too. If the schema was not
+    detected the original url is returned.
+    """
+
+    global __urlRE
+    try:
+        urlRE = __urlRE
+    except NameError:
+        # See rfc3986 for the allowed characters in the components
+        #                              ~~~~~~~~~ scheme ~~~~~~~~   ~~~~~~~~~~~~~ user ~~~~~~~~~~~~~ ~ h+p ~ ~~~~
+        __urlRE = urlRE = re.compile(r"([a-zA-Z][a-zA-Z0-9+-.]*)://([-._~a-zA-Z0-9:%!$&'()*+,;=]+@)?([^/]*)/(.*)")
+
+    m = urlRE.fullmatch(url)
+    if m is not None:
+        return "{}://{}/{}".format(m.group(1), m.group(3), m.group(4))
+
+    global __scpRE
+    try:
+        scpRE = __scpRE
+    except NameError:
+        #                              ~~~~~~~~~~~~~ user ~~~~~~~~~~~~~ ~ h+p ~~ ~~~~
+        __scpRE = scpRE = re.compile(r"([-._~a-zA-Z0-9:%!$&'()*+,;=]+@)?([^/:]+):(.*)")
+
+    m = scpRE.fullmatch(url)
+    if m is not None:
+        return "{}:{}".format(m.group(2), m.group(3))
+
+    # Nothing matched
+    return url
+
 def removePath(path):
     if sys.platform == "win32":
         def onerror(func, path, exc):
@@ -216,9 +249,6 @@ def hashFile(path, hasher=hashlib.sha1):
         logging.getLogger(__name__).warning("Cannot hash file: %s", str(e))
     return m.digest()
 
-def float2ns(v):
-    return int(v * 1000000000)
-
 class DirHasher:
     IGNORE_DIRS = frozenset([
         os.fsencode(".git"),
@@ -231,7 +261,7 @@ class DirHasher:
 
     class FileIndex:
         SIGNATURE        = b'BOB1'
-        CACHE_ENTRY_FMT  = '=QQLQLQ20sH'
+        CACHE_ENTRY_FMT  = '=qqLQLQ20sH'
         CACHE_ENTRY_SIZE = struct.calcsize(CACHE_ENTRY_FMT)
 
         class Stat:
@@ -310,8 +340,8 @@ class DirHasher:
                     self.__inFile.seek(pos)
                 else:
                     self.__outFile.write(DirHasher.FileIndex.SIGNATURE)
-            self.__outFile.write(struct.pack(DirHasher.FileIndex.CACHE_ENTRY_FMT, float2ns(st.st_ctime),
-                float2ns(st.st_mtime), st.st_dev, st.st_ino, st.st_mode, st.st_size,
+            self.__outFile.write(struct.pack(DirHasher.FileIndex.CACHE_ENTRY_FMT, st.st_ctime_ns,
+                st.st_mtime_ns, st.st_dev, st.st_ino, st.st_mode, st.st_size,
                 digest, len(name)))
             self.__outFile.write(name)
 
@@ -319,8 +349,8 @@ class DirHasher:
             while self.__current.name < name:
                 if not self.__readEntry(): break
             e = self.__current
-            res = ((e.name == name) and (e.ctime == float2ns(st.st_ctime)) and
-                (e.mtime == float2ns(st.st_mtime)) and (e.dev == st.st_dev) and
+            res = ((e.name == name) and (e.ctime == st.st_ctime_ns) and
+                (e.mtime == st.st_mtime_ns) and (e.dev == st.st_dev) and
                 (e.ino == st.st_ino) and (e.mode == st.st_mode) and
                 (e.size == st.st_size))
             #if not res: print("Mismatch", e.name, name, e, st)
@@ -460,7 +490,7 @@ def hashPath(path, index=None, ignoreDirs=None):
 
 def binStat(path):
     st = os.stat(path)
-    return struct.pack('=QQLqLQ', float2ns(st.st_ctime), float2ns(st.st_mtime),
+    return struct.pack('=qqLqLQ', st.st_ctime_ns, st.st_mtime_ns,
                        st.st_dev, st.st_ino, st.st_mode, st.st_size)
 
 
